bayespy.nodes.Bernoulli
=======================

.. currentmodule:: bayespy.nodes

.. autoclass:: Bernoulli

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Bernoulli.__init__
      ~Bernoulli.add_plate_axis
      ~Bernoulli.broadcasting_multiplier
      ~Bernoulli.delete
      ~Bernoulli.get_gradient
      ~Bernoulli.get_mask
      ~Bernoulli.get_moments
      ~Bernoulli.get_parameters
      ~Bernoulli.get_riemannian_gradient
      ~Bernoulli.get_shape
      ~Bernoulli.has_plotter
      ~Bernoulli.initialize_from_parameters
      ~Bernoulli.initialize_from_prior
      ~Bernoulli.initialize_from_random
      ~Bernoulli.initialize_from_value
      ~Bernoulli.load
      ~Bernoulli.logpdf
      ~Bernoulli.lower_bound_contribution
      ~Bernoulli.lowerbound
      ~Bernoulli.move_plates
      ~Bernoulli.observe
      ~Bernoulli.pdf
      ~Bernoulli.plot
      ~Bernoulli.random
      ~Bernoulli.save
      ~Bernoulli.set_parameters
      ~Bernoulli.set_plotter
      ~Bernoulli.show
      ~Bernoulli.unobserve
      ~Bernoulli.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Bernoulli.dims
      ~Bernoulli.plates
      ~Bernoulli.plates_multiplier
   
   